.. _sage_package.setuptools:

setuptools utilities for SageMath packages
==========================================

.. automodule:: sage_package.setuptools
   :members:
   :undoc-members:
   :show-inheritance:
